// EA Instructions:
// Make sure to draw 2 trendlines and name them "Support" and "Resistance" accordingly;
// If UPTREND, Trend_type = 1, if DOWNTREND, Trend_type = 2;
// Upper/Lower trendline triggers are in points, NOT PIPS;
// You can only have one open order at a time for the same pair.
// You can use this as a sort of Buy Limit or Sell Limit device, as the orders will only be executed when within Resistance
// & (Resistance - ResLowerTrigger) and Support & (Support + SuppUpperTrigger)

// If you would like to make a donation through Paypal, please do so at rgranzoti at hotmail.com :)

//+------------------------------------------------------------------+
//|                                      SR Trendline Trading EA.mq4 |
//|                                                  Renato Granzoti |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Renato Granzoti"
#property link      "renato.granzoti at gmail.com"

//---- input parameters
extern int       Trend_type = 1; // 1 = UPTREND (will only go LONG within SuppUpperTrigger range of "Support" trendline; 2 = DOWNTREND (will only SHORT within ResLowerTrigger range from "Resistance" trendline;
extern double    Lots = 1.0;
extern int       ResUpperTrigger = 100; // This value will be multiplied by Point
extern int       ResLowerTrigger = 100;
extern int       SuppUpperTrigger = 100;
extern int       SuppLowerTrigger = 100;
extern bool      SoundON = TRUE; // Will emit an audio alert if action is taken when TRUE
extern string    Order_symbol = "GBPUSD"; // You can have 1 open trade at MOST within the same pair

//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
   
   
   double resistancePrice = ObjectGetValueByShift ("Resistance", 0);
   double supportPrice    = ObjectGetValueByShift ("Support", 0);
   
   int orderTicketNumber;
   int totalOrders = OrdersTotal ();
   double orderLots;
        
   if (Trend_type == 1) { // IF IN AN UPTREND
      if (totalOrders == 0) { // AND NO OPEN ORDERS
         if (Ask <= (supportPrice + SuppUpperTrigger*Point) && Ask >= supportPrice) { // BUY WITHIN SUPPORT UPPER TRIGGER ZONE
            orderTicketNumber = OrderSend (Symbol(), OP_BUY, Lots, Ask, 10, (supportPrice - SuppLowerTrigger*Point), 0, "Support BUY", 1, 0, Green);
            if (orderTicketNumber > 0) {
               if (OrderSelect (orderTicketNumber, SELECT_BY_TICKET, MODE_TRADES) == true)   
                  Print("BUY order opened : ",OrderOpenPrice(), " Magic Number: ", OrderMagicNumber());
               if (SoundON == TRUE)
                  PlaySound ("Alert.wav");
            }
            else Print ("Error opening BUY order : ",GetLastError());
         }   
      return (0);
      }
         
      if (totalOrders == 1) { // AND AN ALREADY OPEN ORDER
         OrderSelect (0, SELECT_BY_POS, MODE_TRADES);
         orderTicketNumber = OrderTicket ();
         orderLots = OrderLots ();
         if (OrderSymbol () == Order_symbol) {
            if (Bid <= (supportPrice - SuppLowerTrigger*Point)) {
               OrderClose (orderTicketNumber, orderLots, Bid, 10, Blue);
               return (0);
            }
            if (Bid >= (resistancePrice - ResLowerTrigger*Point)) {
               OrderClose (orderTicketNumber, orderLots, Bid, 10, Blue);
               return (0);
            }
         }
      }        
   }
   if (Trend_type == 2) {
      if (totalOrders == 0) {
         if (Bid >= (resistancePrice - ResLowerTrigger*Point) && Bid <= resistancePrice) {
            orderTicketNumber = OrderSend (Symbol(), OP_SELL, Lots, Bid, 10, (resistancePrice + ResUpperTrigger*Point), 0, "Resistance SELL", 2, 0, Red);
            if (orderTicketNumber > 0) {
               if (OrderSelect (orderTicketNumber, SELECT_BY_TICKET, MODE_TRADES) == true)   
                  Print("SELL order opened : ",OrderOpenPrice(), " Magic Number: ", OrderMagicNumber());
               if (SoundON == TRUE)
                  PlaySound ("Alert.wav");
            } 
            else Print ("Error opening SELL order : ",GetLastError());
         }   
      return (0);
      }
         
      if (totalOrders == 1) {
         OrderSelect (0, SELECT_BY_POS, MODE_TRADES);
         orderTicketNumber = OrderTicket ();
         orderLots = OrderLots ();
         if (OrderSymbol () == Order_symbol) {
            if (Ask >= (resistancePrice + ResUpperTrigger*Point)) {
               OrderClose (orderTicketNumber, orderLots, Ask, 10, Blue);
               return (0);
            }
            if (Ask <= (supportPrice + SuppUpperTrigger*Point)) {
               OrderClose (orderTicketNumber, orderLots, Bid, 10, Blue);
               return (0);
            }
         }
      }
   }           
   return(0);
   }

